import {Avatar} from '@mui/material';
import styled from 'styled-components';
import {connect} from "react-redux";
import {useEffect, useState} from "react";
import {
    changeAuthData,
    changeAuthDataAsync,
    setActiveUserData,
    setUserDataAsync
} from "../store/actionCreators/ActionCreators";
import {useNavigate} from "react-router-dom";
import avatar from "../assets/img/avatarGolub.jpg"
import ModalWindow from "./ModalWindow";
import NewPost from "./NewPost";
import {HeaderButtons} from "../shared/styledComponents";


const HeaderWrapper = styled.div`
  padding: 2px 80px;
  display: flex;
  justify-content: space-evenly;
  align-items: center;
  box-shadow: 0px 10px 13px -7px #000000, 5px 5px 15px 5px rgba(41, 78, 255, 0);
`
const Logotip = styled.p`
font-size: 30px;
  margin: 0;
color:grey;
`


const OwnerHeader = (props) => {

    const [isModal, setisModal] = useState(false);
    const navigate = useNavigate();

    useEffect(() => {
        if (!props.ownerData) {
            props.setUserDataAsync(props.id, true)
        }

    })

    const logout = () => {
        localStorage.authToken = "";
        props.changeAuthData({
            token: "",
            user: ""
        })
        navigate("/auth")

    }

    const feedHandler = () => {
        navigate("/feed")
    }
    const clickHandler = () => {
        props.setUserDataAsync(props.id)
        // props.setActiveUserData(props.ownerData);
        navigate("/profile")
    }

    const toogleModal = () => {
        setisModal(!isModal);
    }


    return (
        <HeaderWrapper>

            <Logotip>=HIPSTARGAM=</Logotip>
            <HeaderButtons onClick={feedHandler}>Feed</HeaderButtons>

            <HeaderButtons onClick={toogleModal}>+ post</HeaderButtons>
            <Avatar onClick={clickHandler}
                    src={props.ownerData && props.ownerData.avatar ? props.ownerData.avatar.url : avatar} alt={"avatar"}
                    sx={{border: "1px solid grey", cursor: "pointer" }}/>
            <HeaderButtons onClick={logout}>Logout</HeaderButtons>
            {isModal && <ModalWindow closeModal={toogleModal}>
                <NewPost closeModal={toogleModal}/>
            </ModalWindow>
            }
        </HeaderWrapper>
    )
};

const mapStateToProps = (state) => {
    return {
        id: state.auth.user.sub.id,
        ownerData: state.ownerData,
    }
}
const mapDispatchToProps = (dispatch) => {
    return {
        changeAuthData: (authData) => dispatch(changeAuthData(authData)),
        changeAuthDataAsync: (authData) => dispatch(changeAuthDataAsync(authData)),
        setUserDataAsync: (id, isOwner) => dispatch(setUserDataAsync(id, isOwner)),
        setActiveUserData: (user) => dispatch(setActiveUserData(user))
    }
}

export default connect(mapStateToProps, mapDispatchToProps)(OwnerHeader);